@@ -29,7 +29,6 @@
 #include <QApplication>
 #include <QCloseEvent>
 #include <QCommandLineParser>
-#include <QDesktopWidget>
 #include <QFile>
 #include <QFrame>
 #include <QLabel>
@@ -79,6 +78,8 @@
 #include "TopWidget.h"
 #include "ZoomToolBar.h"
 
+using namespace Qt::StringLiterals;
+
 /**
  * useful macro for command parsing
  */
@@ -101,23 +102,7 @@
 Kwave::TopWidget::TopWidget(Kwave::App &app)
     :KMainWindow(),
      m_application(app),
-     m_context_map(),
-     m_toolbar_record_playback(Q_NULLPTR),
-     m_toolbar_zoom(Q_NULLPTR),
-     m_menu_manager(Q_NULLPTR),
-     m_mdi_area(Q_NULLPTR),
-     m_action_save(Q_NULLPTR),
-     m_action_save_as(Q_NULLPTR),
-     m_action_close(Q_NULLPTR),
-     m_action_undo(Q_NULLPTR),
-     m_action_redo(Q_NULLPTR),
-     m_action_cut(Q_NULLPTR),
-     m_action_copy(Q_NULLPTR),
-     m_action_erase(Q_NULLPTR),
-     m_action_delete(Q_NULLPTR),
-     m_lbl_status_size(Q_NULLPTR),
-     m_lbl_status_mode(Q_NULLPTR),
-     m_lbl_status_cursor(Q_NULLPTR)
+     m_context_map()
 {
     // status bar items
     QStatusBar *status_bar = statusBar();
@@ -203,20 +188,20 @@ void Kwave::TopWidget::connectContext(Kwave::FileContext *context)
 Kwave::FileContext *Kwave::TopWidget::newFileContext()
 {
     Q_ASSERT(m_toolbar_zoom);
-    if (!m_toolbar_zoom) return Q_NULLPTR;
+    if (!m_toolbar_zoom) return nullptr;
 
     Kwave::FileContext *context =
         new(std::nothrow) Kwave::FileContext(m_application);
-    if (!context) return Q_NULLPTR;
+    if (!context) return nullptr;
     if (!context->init(this)) {
         delete context;
-        return Q_NULLPTR;
+        return nullptr;
     }
 
     // if we are in SDI mode, there is a context but no MDI sub window
     // and in MDI/TAB mode we use this special entry for a context that
     // has just been created but has no sub window yet
-    m_context_map[Q_NULLPTR] = context;
+    m_context_map[nullptr] = context;
 
     // do all signal/slot connections
     connectContext(context);
@@ -231,14 +216,14 @@ Kwave::FileContext *Kwave::TopWidget::newFileContext()
 //***************************************************************************
 Kwave::FileContext *Kwave::TopWidget::currentContext() const
 {
-    if (m_context_map.isEmpty()) return Q_NULLPTR;
+    if (m_context_map.isEmpty()) return nullptr;
 
-    if (m_context_map.contains(Q_NULLPTR)) {
+    if (m_context_map.contains(nullptr)) {
         // the "null" entry is special, it has precedence over all
         // other entries. In SDI mode it is the only one ever and in
         // MDI/TAB mode it is used for a context that has no sub
         // window yet.
-        return m_context_map[Q_NULLPTR];
+        return m_context_map[nullptr];
     }
 
     if (m_mdi_area) {
@@ -248,18 +233,18 @@ Kwave::FileContext *Kwave::TopWidget::currentContext() const
             qWarning("WARNING: unassociated MDI sub window %p?",
                      static_cast<void *>(current_sub));
             QMapIterator<QMdiSubWindow*, Kwave::FileContext*> it(m_context_map);
-            Kwave::FileContext *context = Q_NULLPTR;
+            Kwave::FileContext *context = nullptr;
             while (it.hasNext()) {
                 it.next();
                 context = it.value();
             }
-            return (m_context_map.count() == 1) ? context : Q_NULLPTR;
+            return (m_context_map.count() == 1) ? context : nullptr;
         }
         return m_context_map[current_sub];
     } else {
         // SDI mode
         Q_ASSERT(0 && "SDI mode but no context?");
-        return Q_NULLPTR;
+        return nullptr;
     }
 }
 
@@ -305,7 +290,7 @@ bool Kwave::TopWidget::init()
     Kwave::FileContext *context = newFileContext();
     if (!context) return false;
 
-    QWidget *central_widget = Q_NULLPTR;
+    QWidget *central_widget = nullptr;
     switch (m_application.guiType()) {
         case Kwave::App::GUI_SDI:
             // create a main widget
@@ -329,6 +314,7 @@ bool Kwave::TopWidget::init()
             m_mdi_area->setTabsClosable(true);
             m_mdi_area->setTabsMovable(true);
             break;
+        DEFAULT_IMPOSSIBLE;
     }
 
     if (m_mdi_area) {
@@ -438,7 +424,7 @@ bool Kwave::TopWidget::init()
     updateRecentFiles();
 
     // make sure that everything of our window is visible
-    QRect desk = qApp->desktop()->availableGeometry(this);
+    QRect desk = qApp->primaryScreen()->availableGeometry();
     QRect g    = this->geometry();
     if (!desk.contains(g)) {
         // KDE's stupid geometry management has failed ?
@@ -454,7 +440,7 @@ bool Kwave::TopWidget::init()
 
     // workaround for KDE4: detect first startup and set all toolbars
     // to "only symbols" mode
-    KConfigGroup cfg = KSharedConfig::openConfig()->group("MainWindow");
+    KConfigGroup cfg = KSharedConfig::openConfig()->group(u"MainWindow"_s);
     QString magic = _("3");
     if (cfg.readEntry("toolbars") != magic) {
         qDebug("toolbar layout changed => resetting toolbars to defaults");
@@ -483,13 +469,13 @@ Kwave::TopWidget::~TopWidget()
     closeAllSubWindows();
 
     delete m_toolbar_zoom;
-    m_toolbar_zoom = Q_NULLPTR;
+    m_toolbar_zoom = nullptr;
 
     delete m_toolbar_record_playback;
-    m_toolbar_record_playback = Q_NULLPTR;
+    m_toolbar_record_playback = nullptr;
 
     delete m_menu_manager;
-    m_menu_manager = Q_NULLPTR;
+    m_menu_manager = nullptr;
 
     while (!m_context_map.isEmpty())
         delete m_context_map.take(m_context_map.lastKey());
@@ -542,14 +528,14 @@ QList<Kwave::FileContext *> Kwave::TopWidget::detachAllContexts()
             }
 
             // detach the main widget from the MDI sub window
-            sub->setWidget(Q_NULLPTR);
+            sub->setWidget(nullptr);
             delete sub;
         }
 
         // detach the context from this parent widget
         if (context) {
             context->disconnect();
-            context->setParent(Q_NULLPTR);
+            context->setParent(nullptr);
             if (context->isInUse())
                 list += context;    // in use -> keep
             else
@@ -558,13 +544,13 @@ QList<Kwave::FileContext *> Kwave::TopWidget::detachAllContexts()
     }
 
     // get rid of the MDI area, it should be empty now
-    setCentralWidget(Q_NULLPTR);
+    setCentralWidget(nullptr);
     if (m_mdi_area) {
         delete m_mdi_area;
-        m_mdi_area = Q_NULLPTR;
+        m_mdi_area = nullptr;
     }
 
-    emit sigFileContextSwitched(Q_NULLPTR);
+    emit sigFileContextSwitched(nullptr);
 
     return list;
 }
@@ -572,7 +558,7 @@ QList<Kwave::FileContext *> Kwave::TopWidget::detachAllContexts()
 //***************************************************************************
 void Kwave::TopWidget::insertContext(Kwave::FileContext *context)
 {
-    Kwave::FileContext *old_default_context = Q_NULLPTR;
+    Kwave::FileContext *old_default_context = nullptr;
 
     // if no context was given: create a new empty default context
     if (!context) {
@@ -585,7 +571,7 @@ void Kwave::TopWidget::insertContext(Kwave::FileContext *context)
             context->createMainWidget(geometry().size() * 0.85);
         }
         // prevent it from getting removed again
-        m_context_map.remove(Q_NULLPTR);
+        m_context_map.remove(nullptr);
     }
 
     switch (m_application.guiType()) {
@@ -593,13 +579,13 @@ void Kwave::TopWidget::insertContext(Kwave::FileContext *context)
             // we may have an empty default context -> get rid of it
             Q_ASSERT(m_context_map.count() <= 1);
             if (!m_context_map.isEmpty()) {
-                Kwave::FileContext *ctx = m_context_map[Q_NULLPTR];
-                m_context_map.remove(Q_NULLPTR);
+                Kwave::FileContext *ctx = m_context_map[nullptr];
+                m_context_map.remove(nullptr);
                 Q_ASSERT(ctx != context);
                 old_default_context = ctx;
             }
             // take over the new context
-            m_context_map[Q_NULLPTR] = context;
+            m_context_map[nullptr] = context;
             connectContext(context);
             context->setParent(this);
 
@@ -640,8 +626,8 @@ void Kwave::TopWidget::insertContext(Kwave::FileContext *context)
                 if (!sub) return;
                 sub->adjustSize();
 
-                if (m_context_map.contains(Q_NULLPTR))
-                    m_context_map.remove(Q_NULLPTR);
+                if (m_context_map.contains(nullptr))
+                    m_context_map.remove(nullptr);
                 m_context_map[sub] = context;
 
                 connect(context->mainWidget(), SIGNAL(destroyed(QObject*)),
@@ -690,15 +676,16 @@ void Kwave::TopWidget::insertContext(Kwave::FileContext *context)
                 sub->setHidden(false);
                 m_mdi_area->setActiveSubWindow(sub);
             } else {
-                m_context_map[Q_NULLPTR] = context; // set empty default context
+                m_context_map[nullptr] = context; // set empty default context
             }
 
             break;
         }
+        DEFAULT_IMPOSSIBLE;
     }
 
     // update the menu bar, toolbar etc.
-    emit sigFileContextSwitched(Q_NULLPTR);
+    emit sigFileContextSwitched(nullptr);
     emit sigFileContextSwitched(context);
 
     updateMenu();
@@ -777,7 +764,7 @@ int Kwave::TopWidget::executeCommand(const QString &line)
         else
             return -1;
 
-        KConfigGroup cfg = KSharedConfig::openConfig()->group("Global");
+        KConfigGroup cfg = KSharedConfig::openConfig()->group(u"Global"_s);
         cfg.writeEntry(_("UI Type"), gui_type);
         m_application.switchGuiType(this, new_type);
         result = 0;
@@ -927,7 +914,7 @@ bool Kwave::TopWidget::closeAllSubWindows()
             it.remove();
             if (m_context_map.isEmpty()) {
                 // keep the default context, without a window
-                m_context_map[Q_NULLPTR] = context;
+                m_context_map[nullptr] = context;
                 break;
             }
         }
@@ -945,7 +932,7 @@ int Kwave::TopWidget::newWindow(Kwave::FileContext *&context, const QUrl &url)
             // -> open a new toplevel window
             //    (except for processing commands per kwave: URL
             Kwave::SignalManager *signal_manager = (context) ?
-                context->signalManager() : Q_NULLPTR;
+                context->signalManager() : nullptr;
             if ( signal_manager && !signal_manager->isEmpty() &&
                 (url.scheme().toLower() != Kwave::urlScheme()) )
                 return m_application.newWindow(url);
@@ -957,16 +944,17 @@ int Kwave::TopWidget::newWindow(Kwave::FileContext *&context, const QUrl &url)
         }
         case Kwave::App::GUI_MDI: /* FALLTHROUGH */
         case Kwave::App::GUI_TAB:
+        {
             // MDI or TAB mode: open a new sub window
             Q_ASSERT(m_mdi_area);
             if (!m_mdi_area) return -1;
 
             if (context && context->isEmpty()) {
                 // current context is empty, no main widget etc -> discard it
-                if (m_context_map.contains(Q_NULLPTR)) {
+                if (m_context_map.contains(nullptr)) {
                     // must have been the default context
-                    Q_ASSERT(m_context_map[Q_NULLPTR] == context);
-                    m_context_map.remove(Q_NULLPTR);
+                    Q_ASSERT(m_context_map[nullptr] == context);
+                    m_context_map.remove(nullptr);
                 }
 
                 // NOTE: do not handle the following context switch
@@ -992,6 +980,8 @@ int Kwave::TopWidget::newWindow(Kwave::FileContext *&context, const QUrl &url)
             // insert the context into this instance
             insertContext(context);
             break;
+        }
+        DEFAULT_IMPOSSIBLE;
     }
 
     return 1;
@@ -1325,7 +1315,7 @@ void Kwave::TopWidget::updateMenu()
 {
     const Kwave::FileContext *context = currentContext();
     Kwave::SignalManager *signal_manager =
-        (context) ? context->signalManager() : Q_NULLPTR;
+        (context) ? context->signalManager() : nullptr;
     Q_ASSERT(m_menu_manager);
     if (!m_menu_manager) return;
 
@@ -1363,6 +1353,7 @@ void Kwave::TopWidget::updateMenu()
             m_menu_manager->setItemVisible(_("ID_FILE_NEW_WINDOW"),      false);
             have_window_menu = true;
             break;
+        DEFAULT_IMPOSSIBLE;
     }
 
     if (have_window_menu) {
@@ -1598,7 +1589,7 @@ void Kwave::TopWidget::subWindowDeleted(QObject *obj)
 
     if (m_context_map.isEmpty()) {
         // keep the default context, without a window
-        m_context_map[Q_NULLPTR] = context;
+        m_context_map[nullptr] = context;
     } else {
         // remove the context
         context->release();
@@ -1646,3 +1637,5 @@ void Kwave::TopWidget::dropEvent(QDropEvent *event)
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_TopWidget.cpp"
