@@ -15,7 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
 
 #include <math.h>
 
@@ -27,7 +26,6 @@
 #include <QVBoxLayout>
 
 #include "libkwave/Label.h"
-#include "libkwave/MetaDataList.h"
 #include "libkwave/Sample.h"
 #include "libkwave/SignalManager.h"
 #include "libkwave/String.h"
@@ -77,7 +75,7 @@ Kwave::OverViewWidget::OverViewWidget(Kwave::SignalManager &signal,
     :Kwave::ImageView(parent), m_view_offset(0), m_view_width(0),
      m_signal_length(0), m_selection_start(0), m_selection_length(0),
      m_cursor_position(SAMPLE_INDEX_MAX), m_last_offset(0),
-     m_cache(signal, 0, 0, Q_NULLPTR), m_repaint_timer(), m_labels(),
+     m_cache(signal, 0, 0, nullptr), m_repaint_timer(), m_labels(),
      m_worker_thread(this)
 {
     // check: start() must be called from the GUI thread only!
@@ -139,7 +137,7 @@ void Kwave::OverViewWidget::mousePressEvent(QMouseEvent *e)
     }
 
     // move the clicked position to the center of the viewport
-    sample_index_t offset = pixels2offset(e->x());
+    sample_index_t offset = pixels2offset(e->position().toPoint().x());
     if (offset != m_last_offset) {
         sample_index_t half = (m_view_width / 2);
         offset = (offset > half) ? (offset - half) : 0;
@@ -160,7 +158,7 @@ void Kwave::OverViewWidget::mouseDoubleClickEvent(QMouseEvent *e)
     }
 
     // move the clicked position to the center of the viewport
-    sample_index_t offset = pixels2offset(e->x());
+    sample_index_t offset = pixels2offset(e->position().toPoint().x());
     if (offset != m_last_offset) {
         m_last_offset = offset;
         emit valueChanged(offset);
@@ -463,3 +461,5 @@ void Kwave::OverViewWidget::calculateBitmap()
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_OverViewWidget.cpp"
