@@ -25,7 +25,6 @@
 #include "libkwave/Sample.h"
 #include "libgui/ViewItem.h"
 
-class QWidget;
 
 namespace Kwave
 {
@@ -45,16 +44,16 @@ namespace Kwave
                       Kwave::SignalManager &signal_manager);
 
         /** Destructor */
-        virtual ~SelectionItem() Q_DECL_OVERRIDE;
+        ~SelectionItem() override;
 
         /**
          * Returns flags describing the possible interactions with this object
          * @see Kwave::ViewItem::Flags
          */
-        virtual Kwave::ViewItem::Flags flags() const Q_DECL_OVERRIDE;
+        Kwave::ViewItem::Flags flags() const override;
 
         /** Starts a drag & drop operation. */
-        virtual void startDragging() Q_DECL_OVERRIDE;
+        void startDragging() override;
 
     private:
 
