@@ -60,8 +60,8 @@ Kwave::MultiPlaybackSink::~MultiPlaybackSink()
     if (m_device) {
         m_device->close();
         delete m_device;
+        m_device = nullptr;
     }
-    m_device = Q_NULLPTR;
 
     // discard the buffers
     while (!m_in_buffer.isEmpty())
@@ -122,3 +122,5 @@ void Kwave::MultiPlaybackSink::input(unsigned int track,
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_MultiPlaybackSink.cpp"
