@@ -19,6 +19,7 @@
 #define PLAYBACK_CONTROLLER_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 #include <QList>
@@ -50,7 +51,7 @@ namespace Kwave
      * This class internally manages the logic and handling of the
      * playback position.
      */
-    class Q_DECL_EXPORT PlaybackController: public QObject,
+    class LIBKWAVE_EXPORT PlaybackController: public QObject,
                                             public Kwave::Runnable
     {
     Q_OBJECT
@@ -61,7 +62,7 @@ namespace Kwave
         explicit PlaybackController(Kwave::SignalManager &signal_manager);
 
         /** Destructor */
-        virtual ~PlaybackController() Q_DECL_OVERRIDE;
+        ~PlaybackController() override;
 
     public:
 
@@ -250,7 +251,7 @@ namespace Kwave
     protected:
 
         /** wrapper for our run() function, called from worker thread */
-        virtual void run_wrapper(const QVariant &params) Q_DECL_OVERRIDE;
+        void run_wrapper(const QVariant &params) override;
 
     private:
 
