@@ -58,7 +58,7 @@
 QMap<QString, Kwave::PluginManager::PluginModule>
     Kwave::PluginManager::m_plugin_modules;
 
-Kwave::PluginManager *Kwave::PluginManager::m_active_instance = Q_NULLPTR;
+Kwave::PluginManager *Kwave::PluginManager::m_active_instance = nullptr;
 
 //***************************************************************************
 Kwave::PluginManager::PluginManager(QWidget *parent,
@@ -67,7 +67,7 @@ Kwave::PluginManager::PluginManager(QWidget *parent,
      m_running_plugins(),
      m_parent_widget(parent),
      m_signal_manager(signal_manager),
-     m_view_manager(Q_NULLPTR)
+     m_view_manager(nullptr)
 {
 }
 
@@ -106,13 +106,13 @@ Kwave::PluginManager::~PluginManager()
         if (p.m_use_count == 0) {
             // take out the pointer to the loadable module
             KPluginFactory *factory = p.m_factory;
-            p.m_factory = Q_NULLPTR;
+            p.m_factory = nullptr;
 
             // remove the module from the list
             it = m_plugin_modules.erase(it);
 
             // now the handle of the shared object can be released too
-            if (factory) delete factory;
+            delete factory;
         } else {
             // still in use
             ++it;
@@ -121,7 +121,7 @@ Kwave::PluginManager::~PluginManager()
 
     // we are no longer the active instance
     if (m_active_instance == this)
-        m_active_instance = Q_NULLPTR;
+        m_active_instance = nullptr;
 }
 
 //***************************************************************************
@@ -169,10 +169,11 @@ void Kwave::PluginManager::stopAllPlugins()
     Q_ASSERT(this->thread() == QThread::currentThread());
     Q_ASSERT(this->thread() == qApp->thread());
 
-    if (!m_plugin_instances.isEmpty())
+    if (!m_plugin_instances.isEmpty()) {
         foreach (const KwavePluginPointer &plugin, m_plugin_instances)
             if (plugin && plugin->isRunning())
                 plugin->stop() ;
+    }
 
     sync();
 }
@@ -189,7 +190,7 @@ Kwave::Plugin *Kwave::PluginManager::createPluginInstance(const QString &name)
         Kwave::MessageBox::error(m_parent_widget,
             i18n("The plugin '%1' is unknown or invalid.", name),
             i18n("Error On Loading Plugin"));
-        return Q_NULLPTR;
+        return nullptr;
     }
 
     PluginModule &info = m_plugin_modules[name];
@@ -207,7 +208,7 @@ Kwave::Plugin *Kwave::PluginManager::createPluginInstance(const QString &name)
     Q_ASSERT(plugin);
     if (!plugin) {
         qWarning("PluginManager::loadPlugin('%s'): out of memory", DBG(name));
-        return Q_NULLPTR;
+        return nullptr;
     }
     // now we have a newly created plugin, the use count is 1
 
@@ -247,7 +248,7 @@ int Kwave::PluginManager::executePlugin(const QString &name,
         if (!m_plugin_instances.contains(plugin)) {
             qDebug("PluginManager: plugin closed itself in start()");
             result = -1;
-            plugin = Q_NULLPTR;
+            plugin = nullptr;
         }
 
         if (plugin && (result >= 0)) {
@@ -299,9 +300,10 @@ bool Kwave::PluginManager::canClose()
     Q_ASSERT(this->thread() == QThread::currentThread());
     Q_ASSERT(this->thread() == qApp->thread());
 
-    if (!m_plugin_instances.isEmpty())
+    if (!m_plugin_instances.isEmpty()) {
         foreach (const KwavePluginPointer &plugin, m_plugin_instances)
             if (plugin && !plugin->canClose()) return false;
+    }
 
     return true;
 }
@@ -313,9 +315,10 @@ bool Kwave::PluginManager::onePluginRunning()
     Q_ASSERT(this->thread() == QThread::currentThread());
     Q_ASSERT(this->thread() == qApp->thread());
 
-    if (!m_plugin_instances.isEmpty())
+    if (!m_plugin_instances.isEmpty()) {
         foreach (const KwavePluginPointer &plugin, m_plugin_instances)
             if (plugin && plugin->isRunning()) return true;
+    }
 
     return false;
 }
@@ -470,7 +473,7 @@ Kwave::SampleSink *Kwave::PluginManager::openMultiTrackPlayback(
     Kwave::PlayBackDevice *device =
         m_signal_manager.playbackController().openDevice(
             tracks, playback_params);
-    if (!device) return Q_NULLPTR;
+    if (!device) return nullptr;
 
     // create the multi track playback sink
     Kwave::SampleSink *sink = new(std::nothrow)
@@ -683,7 +686,7 @@ void Kwave::PluginManager::searchPluginModules()
         qDebug("%16s %5s written by %s", DBG(name), DBG(settings), DBG(author));
     }
 
-    qDebug("--- \n found %d plugins\n", m_plugin_modules.count());
+    qDebug("--- \n found %lld plugins\n", m_plugin_modules.count());
 }
 
 //***************************************************************************
@@ -721,3 +724,5 @@ void Kwave::PluginManager::migratePluginToActiveContext(Kwave::Plugin *plugin)
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_PluginManager.cpp"
