@@ -20,6 +20,7 @@
 #define UNDO_MODIFY_META_DATA_ACTION_H
 
 #include "config.h"
+#include "libkwave_export.h"
 
 #include <QtGlobal>
 #include <QString>
@@ -33,7 +34,7 @@ namespace Kwave
     /**
      * Undo action for modifying meta data
      */
-    class Q_DECL_EXPORT UndoModifyMetaDataAction: public UndoAction
+    class LIBKWAVE_EXPORT UndoModifyMetaDataAction: public UndoAction
     {
     public:
 
@@ -44,28 +45,28 @@ namespace Kwave
         explicit UndoModifyMetaDataAction(const Kwave::MetaDataList &meta_data);
 
         /** Destructor */
-        virtual ~UndoModifyMetaDataAction() Q_DECL_OVERRIDE;
+        ~UndoModifyMetaDataAction() override;
 
         /**
         * Returns a verbose short description of the action.
         */
-        virtual QString description() Q_DECL_OVERRIDE;
+        QString description() override;
 
         /** @see UndoAction::undoSize() */
-        virtual qint64 undoSize() Q_DECL_OVERRIDE;
+        qint64 undoSize() override;
 
         /** @see UndoAction::redoSize() */
-        virtual qint64 redoSize() Q_DECL_OVERRIDE;
+        qint64 redoSize() override;
 
         /** @see UndoAction::store() */
-        virtual bool store(Kwave::SignalManager &manager) Q_DECL_OVERRIDE;
+        bool store(Kwave::SignalManager &manager) override;
 
         /** @see UndoAction::undo() */
-        virtual Kwave::UndoAction *undo(Kwave::SignalManager &manager,
-                                        bool with_redo) Q_DECL_OVERRIDE;
+        Kwave::UndoAction *undo(Kwave::SignalManager &manager,
+                                        bool with_redo) override;
 
         /** dump, for debugging purposes */
-        virtual void dump(const QString &indent) Q_DECL_OVERRIDE;
+        void dump(const QString &indent) override;
 
     protected:
 
