@@ -59,7 +59,7 @@ Kwave::RIFFParser::RIFFParser(QIODevice &device,
                               const QStringList &main_chunks,
                               const QStringList &known_subchunks)
     :m_dev(device),
-     m_root(Q_NULLPTR, "", "", toUint32(device.size()), 0,
+     m_root(nullptr, "", "", toUint32(device.size()), 0,
             toUint32(device.size())),
      m_main_chunk_names(main_chunks), m_sub_chunk_names(known_subchunks),
      m_endianness(Kwave::UnknownEndian), m_cancel(false)
@@ -159,7 +159,7 @@ void Kwave::RIFFParser::detectEndianness()
     double half = static_cast<double>(m_dev.size() >> 1);
 
     // loop over all chunk names
-    int count = names.count();
+    int count = static_cast<int>(names.count());
     int index = 0;
     foreach (QString chunk_name, names) {
         // scan all offsets where the name matches
@@ -253,11 +253,11 @@ Kwave::RIFFChunk *Kwave::RIFFParser::addChunk(
     Kwave::RIFFChunk *chunk = new Kwave::RIFFChunk(
         parent, name, format, length, phys_offset, phys_length);
     Q_ASSERT(chunk);
-    if (!chunk) return Q_NULLPTR;
+    if (!chunk) return nullptr;
     chunk->setType(type);
 
     // sort the chunk into the parent, order by physical start
-    Kwave::RIFFChunk *before = Q_NULLPTR;
+    Kwave::RIFFChunk *before = nullptr;
     Kwave::RIFFChunkList &chunks = parent->subChunks();
     foreach (Kwave::RIFFChunk *c, chunks) {
         if (!c) continue;
@@ -268,7 +268,7 @@ Kwave::RIFFChunk *Kwave::RIFFParser::addChunk(
         }
     }
 
-    int index = (before) ? chunks.indexOf(before) : chunks.size();
+    qsizetype index = (before) ? chunks.indexOf(before) : chunks.size();
     chunks.insert(index, chunk);
 
     return chunk;
@@ -456,7 +456,7 @@ Kwave::RIFFChunk *Kwave::RIFFParser::findChunk(const QByteArray &path)
         }
     }
 
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 //***************************************************************************
@@ -537,7 +537,7 @@ Kwave::RIFFChunk *Kwave::RIFFParser::chunkAt(quint32 offset)
     listAllChunks(m_root, list);
     foreach (Kwave::RIFFChunk *chunk, list)
         if (chunk && chunk->physStart() == offset) return chunk;
-        return Q_NULLPTR;
+        return nullptr;
 }
 
 //***************************************************************************
@@ -554,7 +554,7 @@ Kwave::RIFFChunk *Kwave::RIFFParser::findMissingChunk(const QByteArray &name)
     listAllChunks(m_root, all_chunks);
 
     int index = 0;
-    int count = all_chunks.count();
+    int count = static_cast<int>(all_chunks.count());
     foreach (Kwave::RIFFChunk *chunk, all_chunks) {
         if (m_cancel) break;
         if (!chunk) continue;
@@ -596,7 +596,7 @@ Kwave::RIFFChunk *Kwave::RIFFParser::findMissingChunk(const QByteArray &name)
         }
     }
 
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 //***************************************************************************
@@ -664,10 +664,8 @@ void Kwave::RIFFParser::collectGarbage()
                 // -> convert into a garbage chunk !
                 chunk->setType(Kwave::RIFFChunk::Garbage);
                 chunk->setLength(end - start + 4 + 1);
-                while (!subchunks.isEmpty()) {
-                    Kwave::RIFFChunk *c = subchunks.takeLast();
-                    if (c) delete c;
-                }
+                while (!subchunks.isEmpty())
+                    delete subchunks.takeLast();
                 chunks.clear();
 
                 // start over the scan...
@@ -822,3 +820,5 @@ void Kwave::RIFFParser::cancel()
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_RIFFParser.cpp"
