@@ -238,7 +238,7 @@ bool Kwave::K3BExportPlugin::detectBlockMetaData(
         placeholder_esc = Kwave::Parser::escape(placeholder);
         if (pattern_esc.contains(placeholder_esc)) {
             const QString rx_string = _("(.+)");
-            int pos = pattern.indexOf(placeholder);
+            int pos = static_cast<int>(pattern.indexOf(placeholder));
             pattern_esc.replace(placeholder_esc, rx_string);
             map_result.insert(pos, map_patterns[placeholder]);
         }
@@ -293,7 +293,7 @@ QStringList *Kwave::K3BExportPlugin::setup(QStringList &params)
 
     sample_index_t selection_left  = 0;
     sample_index_t selection_right = 0;
-    selection(Q_NULLPTR, &selection_left, &selection_right, false);
+    selection(nullptr, &selection_left, &selection_right, false);
 
     // enable the "selection only" checkbox only if there is something
     // selected but not everything
@@ -319,19 +319,19 @@ QStringList *Kwave::K3BExportPlugin::setup(QStringList &params)
             m_export_location,
             m_overwrite_policy
         );
-    if (!dialog) return Q_NULLPTR;
+    if (!dialog) return nullptr;
 
     dialog->setWindowTitle(description());
     if ((dialog->exec() != QDialog::Accepted) || !dialog) {
         delete dialog;
-        return Q_NULLPTR;
+        return nullptr;
     }
 
     QStringList *list = new(std::nothrow) QStringList();
     Q_ASSERT(list);
     if (!list) {
         delete dialog;
-        return Q_NULLPTR;
+        return nullptr;
     }
 
     // user has pressed "OK"
@@ -339,7 +339,7 @@ QStringList *Kwave::K3BExportPlugin::setup(QStringList &params)
     if (url.isEmpty()) {
         delete dialog;
         delete list;
-        return Q_NULLPTR;
+        return nullptr;
     }
 
     QString name = url.path();
@@ -369,7 +369,7 @@ QStringList *Kwave::K3BExportPlugin::setup(QStringList &params)
         QString::number(overwrite_policy) + _(")")
     );
 
-    if (dialog) delete dialog;
+    delete dialog;
     return list;
 }
 
@@ -612,7 +612,7 @@ int Kwave::K3BExportPlugin::start(QStringList &params)
 
     // check: only mono or stereo files are supported
     if ((tracks.count() != 1) && (tracks.count() != 2)) {
-        qWarning("sorry, K3b can not handle %u tracks", tracks.count());
+        qWarning("sorry, K3b can not handle %llu tracks", tracks.count());
         Kwave::MessageBox::sorry(parentWidget(), i18n(
             "Only mono and stereo files can be used for an audio CD. "
             "You can either deselect some channels or export the file "
@@ -634,7 +634,7 @@ int Kwave::K3BExportPlugin::start(QStringList &params)
 
     // create a list of blocks to save, but not yet the output file names
     scanBlocksToSave(base, selection_left, selection_right);
-    unsigned int count = m_block_info.count();
+    unsigned int count = static_cast<unsigned int>(m_block_info.count());
     if (!count)
         return -EINVAL;
 
@@ -799,3 +799,5 @@ QStringList Kwave::K3BExportPlugin::knownPatterns()
 #include "K3BExportPlugin.moc"
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_K3BExportPlugin.cpp"
