@@ -40,10 +40,10 @@ namespace Kwave
         Normalizer();
 
         /** Destructor */
-        virtual ~Normalizer() Q_DECL_OVERRIDE;
+        ~Normalizer() override;
 
         /** does the calculation */
-        virtual void goOn() Q_DECL_OVERRIDE;
+        void goOn() override;
 
     signals:
 
