@@ -163,7 +163,7 @@ template <class T, int (allocator)(T**), void (deleter)(T*)>
 public:
     /** constructor, creates an object using the allocator function */
     AlsaMallocWrapper()
-        :m_data(Q_NULLPTR)
+        :m_data(nullptr)
     {
         allocator(&m_data);
     }
@@ -172,7 +172,7 @@ public:
     virtual ~AlsaMallocWrapper()
     {
         if (m_data) deleter(m_data);
-        m_data = Q_NULLPTR;
+        m_data = nullptr;
     }
 
     /** conversion operator, returns the ALSA object */
@@ -192,7 +192,7 @@ private:
 Kwave::PlayBackALSA::PlayBackALSA()
     :Kwave::PlayBackDevice(),
     m_device_name(),
-    m_handle(Q_NULLPTR),
+    m_handle(nullptr),
     m_rate(0),
     m_channels(0),
     m_bits(0),
@@ -204,7 +204,7 @@ Kwave::PlayBackALSA::PlayBackALSA()
     m_format(),
     m_chunk_size(0),
     m_supported_formats(),
-    m_encoder(Q_NULLPTR)
+    m_encoder(nullptr)
 {
 }
 
@@ -222,8 +222,8 @@ int Kwave::PlayBackALSA::setFormat(snd_pcm_hw_params_t *hw_params,
     m_format = SND_PCM_FORMAT_UNKNOWN;
     m_bits = 0;
     m_bytes_per_sample = 0;
-    if (m_encoder) delete m_encoder;
-    m_encoder = Q_NULLPTR;
+    delete m_encoder;
+    m_encoder = nullptr;
 
     // get a format that matches the number of bits
     int format_index = mode2format(bits);
@@ -314,7 +314,7 @@ QList<int> Kwave::PlayBackALSA::detectSupportedFormats(const QString &device)
         foreach (int index, m_supported_formats) {
             const snd_pcm_format_t *f = &_known_formats[index];
             if (*f == *fmt) {
-                fmt = Q_NULLPTR;
+                fmt = nullptr;
                 break;
             }
         }
@@ -345,7 +345,7 @@ int Kwave::PlayBackALSA::openDevice(const QString &device, unsigned int rate,
                                     unsigned int channels, unsigned int bits)
 {
     int err;
-    snd_output_t *output = Q_NULLPTR;
+    snd_output_t *output = nullptr;
     ALSA_MALLOC_WRAPPER(snd_pcm_hw_params) hw_params;
     ALSA_MALLOC_WRAPPER(snd_pcm_sw_params) sw_params;
     snd_pcm_uframes_t buffer_size;
@@ -357,7 +357,7 @@ int Kwave::PlayBackALSA::openDevice(const QString &device, unsigned int rate,
 
     m_chunk_size = 0;
     if (m_handle) snd_pcm_close(m_handle);
-    m_handle = Q_NULLPTR;
+    m_handle = nullptr;
 
     // translate verbose name to internal ALSA name
     QString alsa_device = alsaDeviceName(device);
@@ -433,7 +433,7 @@ int Kwave::PlayBackALSA::openDevice(const QString &device, unsigned int rate,
 
     unsigned int rrate = rate;
     err = snd_pcm_hw_params_set_rate_near(m_handle, hw_params, &rrate,
-                                          Q_NULLPTR);
+                                          nullptr);
     if (err < 0) {
         qWarning("Cannot set sample rate: %s", snd_strerror(err));
         snd_output_close(output);
@@ -450,7 +450,7 @@ int Kwave::PlayBackALSA::openDevice(const QString &device, unsigned int rate,
     }
 
     err = snd_pcm_hw_params_get_buffer_time_max(hw_params, &buffer_time,
-                                                Q_NULLPTR);
+                                                nullptr);
     Q_ASSERT(err >= 0);
     if (buffer_time > 500000) buffer_time = 500000;
     if (buffer_time > 0)
@@ -460,15 +460,15 @@ int Kwave::PlayBackALSA::openDevice(const QString &device, unsigned int rate,
 
     if (period_time > 0) {
         err = snd_pcm_hw_params_set_period_time_near(m_handle, hw_params,
-                                                     &period_time, Q_NULLPTR);
+                                                     &period_time, nullptr);
     } else {
         err = snd_pcm_hw_params_set_period_size_near(m_handle, hw_params,
-                                                     &period_frames, Q_NULLPTR);
+                                                     &period_frames, nullptr);
     }
     Q_ASSERT(err >= 0);
     if (buffer_time > 0) {
         err = snd_pcm_hw_params_set_buffer_time_near(m_handle, hw_params,
-                                                     &buffer_time, Q_NULLPTR);
+                                                     &buffer_time, nullptr);
     } else {
         err = snd_pcm_hw_params_set_buffer_size_near(m_handle, hw_params,
                                                      &buffer_frames);
@@ -484,7 +484,7 @@ int Kwave::PlayBackALSA::openDevice(const QString &device, unsigned int rate,
         return err;
     }
 
-    snd_pcm_hw_params_get_period_size(hw_params, &m_chunk_size, Q_NULLPTR);
+    snd_pcm_hw_params_get_period_size(hw_params, &m_chunk_size, nullptr);
     snd_pcm_hw_params_get_buffer_size(hw_params, &buffer_size);
     if (m_chunk_size == buffer_size) {
         qWarning("Can't use period equal to buffer size (%lu == %lu)",
@@ -555,9 +555,9 @@ QString Kwave::PlayBackALSA::open(const QString &device, double rate,
 
     // close the previous device
     if (m_handle) snd_pcm_close(m_handle);
-    m_handle = Q_NULLPTR;
-    if (m_encoder) delete m_encoder;
-    m_encoder = Q_NULLPTR;
+    m_handle = nullptr;
+    delete m_encoder;
+    m_encoder = nullptr;
 
     // initialize the list of supported formats
     m_supported_formats = detectSupportedFormats(device);
@@ -603,7 +603,7 @@ QString Kwave::PlayBackALSA::open(const QString &device, double rate,
     if (n < 1) n = 1;
     m_buffer_size = n * chunk_bytes;
     m_buffer.resize(m_buffer_size);
-    m_buffer_size = m_buffer.size();
+    m_buffer_size = static_cast<unsigned int>(m_buffer.size());
 
 //     qDebug("PlayBackALSA::open: OK, buffer resized to %u bytes",
 //            m_buffer_size);
@@ -723,11 +723,11 @@ int Kwave::PlayBackALSA::close()
 
     // close the device handle
     if (m_handle) snd_pcm_close(m_handle);
-    m_handle = Q_NULLPTR;
+    m_handle = nullptr;
 
     // get rid of the old sample encoder
-    if (m_encoder) delete m_encoder;
-    m_encoder = Q_NULLPTR;
+    delete m_encoder;
+    m_encoder = nullptr;
 
     // clear the list of supported formats, nothing open -> nothing supported
     m_supported_formats.clear();
@@ -920,11 +920,11 @@ snd_pcm_t *Kwave::PlayBackALSA::openDevice(const QString &device)
     // translate verbose name to internal ALSA name
     QString alsa_device = alsaDeviceName(device);
 
-    if (!alsa_device.length()) return Q_NULLPTR;
+    if (!alsa_device.length()) return nullptr;
 
     // workaround for bug in ALSA
     // if the device name ends with "," -> invalid name
-    if (alsa_device.endsWith(_(","))) return Q_NULLPTR;
+    if (alsa_device.endsWith(_(","))) return nullptr;
 
     if (!pcm) {
         // open the device in case it's not already open
@@ -932,7 +932,7 @@ snd_pcm_t *Kwave::PlayBackALSA::openDevice(const QString &device)
                                SND_PCM_STREAM_PLAYBACK,
                                SND_PCM_NONBLOCK);
         if (err < 0) {
-            pcm = Q_NULLPTR;
+            pcm = nullptr;
             qWarning("PlayBackALSA::openDevice('%s') - failed, err=%d (%s)",
                      DBG(alsa_device), err, snd_strerror(err));
         }
