@@ -21,8 +21,8 @@
 #include "config.h"
 #ifdef HAVE_QT_AUDIO_SUPPORT
 
-#include <QAudio>
-#include <QAudioDeviceInfo>
+#include <QtAudio>
+#include <QAudioDevice>
 #include <QByteArray>
 #include <QIODevice>
 #include <QList>
@@ -37,8 +37,7 @@
 #include "libkwave/PlayBackDevice.h"
 #include "libkwave/SampleArray.h"
 
-class QAudioOutput;
-class QIODevice;
+class QAudioSink;
 
 namespace Kwave
 {
@@ -55,7 +54,7 @@ namespace Kwave
         PlayBackQt();
 
         /** Destructor */
-        virtual ~PlayBackQt() Q_DECL_OVERRIDE;
+        ~PlayBackQt() override;
 
         /**
          * Opens the device for playback.
@@ -63,25 +62,25 @@ namespace Kwave
          */
         virtual QString open(const QString &device, double rate,
                              unsigned int channels, unsigned int bits,
-                             unsigned int bufbase) Q_DECL_OVERRIDE;
+                             unsigned int bufbase) override;
 
         /**
          * Writes an array of samples to the output device.
          * @see PlayBackDevice::write
          */
-        virtual int write(const Kwave::SampleArray &samples) Q_DECL_OVERRIDE;
+        int write(const Kwave::SampleArray &samples) override;
 
         /**
          * Closes the output device.
          * @see PlayBackDevice::close
          */
-        virtual int close() Q_DECL_OVERRIDE;
+        int close() override;
 
         /** return a string list with supported device names */
-        virtual QStringList supportedDevices() Q_DECL_OVERRIDE;
+        QStringList supportedDevices() override;
 
         /** return a string suitable for a "File Open..." dialog */
-        virtual QString fileFilter() Q_DECL_OVERRIDE;
+        QString fileFilter() override;
 
         /**
          * returns a list of supported bits per sample resolutions
@@ -91,7 +90,7 @@ namespace Kwave
          * @return list of supported bits per sample, or empty on errors
          */
         virtual QList<unsigned int> supportedBits(const QString &device)
-            Q_DECL_OVERRIDE;
+            override;
 
         /**
          * Detect the minimum and maximum number of channels.
@@ -105,7 +104,7 @@ namespace Kwave
          */
         virtual int detectChannels(const QString &device,
                                    unsigned int &min, unsigned int &max)
-            Q_DECL_OVERRIDE;
+            override;
 
     private slots:
 
@@ -129,13 +128,12 @@ namespace Kwave
         void scanDevices();
 
         /**
-         * Gets the full device info of a playback device, identified by
-         * the device name.
+         * Gets an audio device, identified by the device name.
          *
          * @param device name of the device or empty string for default
-         * @return a QAudioDeviceInfo
+         * @return a QAudioDevice
          */
-        QAudioDeviceInfo deviceInfo(const QString &device) const;
+        QAudioDevice getDevice(const QString &device) const;
 
     private:
 
@@ -146,7 +144,7 @@ namespace Kwave
             Buffer();
 
             /** destructor */
-            virtual ~Buffer() Q_DECL_OVERRIDE;
+            ~Buffer() override;
 
             /**
              * start filling the buffer
@@ -179,7 +177,7 @@ namespace Kwave
              * @param len number of bytes to read
              * @return number of bytes that have been read
              */
-            virtual qint64 readData(char *data, qint64 len) Q_DECL_OVERRIDE;
+            qint64 readData(char *data, qint64 len) override;
 
             /**
              * write data into the buffer, called from our own worker thread
@@ -188,10 +186,10 @@ namespace Kwave
              * @return number of bytes written
              */
             virtual qint64 writeData(const char *data, qint64 len)
-                Q_DECL_OVERRIDE;
+                override;
 
             /** returns the number of bytes available for reading */
-            virtual qint64 bytesAvailable() const Q_DECL_OVERRIDE;
+            qint64 bytesAvailable() const override;
 
         private:
 
@@ -227,13 +225,13 @@ namespace Kwave
          * into Qt audio output device names
          * (key = verbose name, data = Qt output device name)
          */
-        QMap<QString, QString> m_device_name_map;
+        QMap<QString, QByteArray> m_device_name_map;
 
         /** list of available Qt output devices */
-        QList<QAudioDeviceInfo> m_available_devices;
+        QList<QAudioDevice> m_available_devices;
 
         /** Qt audio output instance */
-        QAudioOutput *m_output;
+        QAudioSink *m_output;
 
         /** buffer size in bytes */
         unsigned int m_buffer_size;
