@@ -134,7 +134,7 @@ int Kwave::RecordOSS::read(QByteArray &buffer, unsigned int offset)
     struct timeval tv;
     int retval;
     int read_bytes = 0;
-    unsigned int length = buffer.size();
+    unsigned int length = static_cast<unsigned int>(buffer.size());
 
 //     qDebug("RecordOSS::read(), offset=%d, length=%d", offset, length);
     Q_ASSERT(m_fd >= 0);
@@ -182,7 +182,7 @@ int Kwave::RecordOSS::read(QByteArray &buffer, unsigned int offset)
 
         tv.tv_sec  = timeout;
         tv.tv_usec = 0;
-        retval = select(m_fd+1, &rfds, Q_NULLPTR, Q_NULLPTR, &tv);
+        retval = select(m_fd+1, &rfds, nullptr, nullptr, &tv);
 
         if (retval == -1) {
             if (errno == EINTR)
@@ -238,7 +238,7 @@ static bool addIfExists(QStringList &list, const QString &name)
         addIfExists(list, name.arg(_("")));
 
         // loop over the list and try until a suffix does not exist
-        for (unsigned int index=0; index < 64; index++)
+        for (unsigned int index = 0; index < 64; index++)
             addIfExists(list, name.arg(index));
     } else {
         // check a single name
@@ -266,8 +266,8 @@ static void scanFiles(QStringList &list, const QString &dirname,
     dir.setSorting(QDir::Name);
     files = dir.entryList();
 
-    for (QStringList::Iterator it = files.begin(); it != files.end(); ++it) {
-        QString devicename = dirname + QDir::separator() + (*it);
+    for (QString &it : files) {
+        QString devicename = dirname + QDir::separator() + it;
         addIfExists(list, devicename);
     }
 }
