@@ -208,10 +208,10 @@ Kwave::RecordPulseAudio::RecordPulseAudio()
     m_bits_per_sample(0),
     m_supported_formats(),
     m_initialized(false),
-    m_pa_proplist(Q_NULLPTR),
-    m_pa_mainloop(Q_NULLPTR),
-    m_pa_context(Q_NULLPTR),
-    m_pa_stream(Q_NULLPTR),
+    m_pa_proplist(nullptr),
+    m_pa_mainloop(nullptr),
+    m_pa_context(nullptr),
+    m_pa_stream(nullptr),
     m_pa_device(),
     m_name(i18n("Kwave record")),
     m_device_list()
@@ -375,6 +375,7 @@ void Kwave::RecordPulseAudio::notifyContext(pa_context *c)
         case PA_CONTEXT_FAILED:
             m_mainloop_signal.wakeAll();
             break;
+        DEFAULT_IGNORE;
     }
 }
 
@@ -652,7 +653,7 @@ int Kwave::RecordPulseAudio::close()
 
         pa_stream_unref(m_pa_stream);
     }
-    m_pa_stream = Q_NULLPTR;
+    m_pa_stream = nullptr;
 
     // we need to re-initialize the next time
     m_initialized = false;
@@ -665,7 +666,7 @@ int Kwave::RecordPulseAudio::read(QByteArray& buffer, unsigned int offset)
     if (buffer.isNull() || buffer.isEmpty())
         return 0; // no buffer, nothing to do
 
-    unsigned int length = buffer.size();
+    unsigned int length = static_cast<unsigned int>(buffer.size());
 
     // we configure our device at a late stage, not on the fly like in OSS
     if (!m_initialized) {
@@ -679,12 +680,12 @@ int Kwave::RecordPulseAudio::read(QByteArray& buffer, unsigned int offset)
     size_t readableSize = pa_stream_readable_size(m_pa_stream);
     if (readableSize > freeBytes) {
         size_t additional_size = readableSize - freeBytes;
-        buffer.resize(static_cast<int>(length + additional_size));
+        buffer.resize(length + additional_size);
     }
 
     size_t readLength = 0;
     if (readableSize > 0) {
-        const void *audioBuffer = Q_NULLPTR;
+        const void *audioBuffer = nullptr;
         pa_stream_peek(m_pa_stream, &audioBuffer, &readLength);
 
         if (offset + readLength > Kwave::toUint(buffer.length())) {
@@ -802,7 +803,7 @@ int Kwave::RecordPulseAudio::initialize(uint32_t buffer_size)
 
     if (result < 0) {
         pa_stream_unref(m_pa_stream);
-        m_pa_stream = Q_NULLPTR;
+        m_pa_stream = nullptr;
         qWarning("Failed to open a PulseAudio stream for record %s",
                  pa_strerror(pa_context_errno(m_pa_context)));
         return -1;
@@ -855,7 +856,7 @@ void Kwave::RecordPulseAudio::run_wrapper(const QVariant &params)
 {
     Q_UNUSED(params)
     m_mainloop_lock.lock();
-    pa_mainloop_run(m_pa_mainloop, Q_NULLPTR);
+    pa_mainloop_run(m_pa_mainloop, nullptr);
     m_mainloop_lock.unlock();
     qDebug("RecordPulseAudio::run_wrapper - done.");
 }
@@ -936,9 +937,9 @@ bool Kwave::RecordPulseAudio::connectToServer()
     bool failed = false;
     int error = pa_context_connect(
         m_pa_context,                       // context
-        Q_NULLPTR,                          // server
+        nullptr,                          // server
         static_cast<pa_context_flags_t>(0), // flags
-        Q_NULLPTR                           // API
+        nullptr                           // API
     );
     if (error < 0)
     {
@@ -996,19 +997,19 @@ void Kwave::RecordPulseAudio::disconnectFromServer()
     if (m_pa_context) {
         pa_context_disconnect(m_pa_context);
         pa_context_unref(m_pa_context);
-        m_pa_context  = Q_NULLPTR;
+        m_pa_context  = nullptr;
     }
 
     // stop and free the main loop
     if (m_pa_mainloop) {
         pa_mainloop_free(m_pa_mainloop);
-        m_pa_mainloop = Q_NULLPTR;
+        m_pa_mainloop = nullptr;
     }
 
     // release the property list
     if (m_pa_proplist) {
         pa_proplist_free(m_pa_proplist);
-        m_pa_proplist = Q_NULLPTR;
+        m_pa_proplist = nullptr;
     }
 
 }
