@@ -63,12 +63,12 @@ KWAVE_PLUGIN(sonagram, SonagramPlugin)
 Kwave::SonagramPlugin::SonagramPlugin(QObject *parent,
                                       const QVariantList &args)
     :Kwave::Plugin(parent, args),
-     m_sonagram_window(Q_NULLPTR),
-     m_selection(Q_NULLPTR),
+     m_sonagram_window(nullptr),
+     m_selection(nullptr),
      m_slices(0), m_fft_points(0),
      m_window_type(Kwave::WINDOW_FUNC_NONE), m_color(true),
      m_track_changes(true), m_follow_selection(false), m_image(),
-     m_overview_cache(Q_NULLPTR), m_slice_pool(), m_valid(MAX_SLICES, false),
+     m_overview_cache(nullptr), m_slice_pool(), m_valid(MAX_SLICES, false),
      m_pending_jobs(), m_lock_job_list(), m_future(),
      m_repaint_timer()
 {
@@ -89,17 +89,17 @@ Kwave::SonagramPlugin::~SonagramPlugin()
 {
     m_repaint_timer.stop();
 
-    if (m_sonagram_window) delete m_sonagram_window;
-    m_sonagram_window = Q_NULLPTR;
+    delete m_sonagram_window;
+    m_sonagram_window = nullptr;
 
-    if (m_selection) delete m_selection;
-    m_selection = Q_NULLPTR;
+    delete m_selection;
+    m_selection = nullptr;
 }
 
 //***************************************************************************
 QStringList *Kwave::SonagramPlugin::setup(QStringList &previous_params)
 {
-    QStringList *result = Q_NULLPTR;
+    QStringList *result = nullptr;
 
     // try to interprete the list of previous parameters, ignore errors
     if (previous_params.count()) interpreteParameters(previous_params);
@@ -107,7 +107,7 @@ QStringList *Kwave::SonagramPlugin::setup(QStringList &previous_params)
     QPointer<Kwave::SonagramDialog> dlg =
         new(std::nothrow) Kwave::SonagramDialog(*this);
     Q_ASSERT(dlg);
-    if (!dlg) return Q_NULLPTR;
+    if (!dlg) return nullptr;
 
     dlg->setWindowFunction(m_window_type);
     dlg->setColorMode(m_color ? 1 : 0);
@@ -160,12 +160,12 @@ int Kwave::SonagramPlugin::interpreteParameters(QStringList &params)
 int Kwave::SonagramPlugin::start(QStringList &params)
 {
     // clean up leftovers from last run
-    if (m_sonagram_window) delete m_sonagram_window;
-    m_sonagram_window = Q_NULLPTR;
-    if (m_selection)       delete m_selection;
-    m_selection = Q_NULLPTR;
-    if (m_overview_cache)  delete m_overview_cache;
-    m_overview_cache = Q_NULLPTR;
+    delete m_sonagram_window;
+    m_sonagram_window = nullptr;
+    delete m_selection;
+    m_selection = nullptr;
+    delete m_overview_cache;
+    m_overview_cache = nullptr;
 
     Kwave::SignalManager &sig_mgr = signalManager();
 
@@ -187,7 +187,7 @@ int Kwave::SonagramPlugin::start(QStringList &params)
     QVector<unsigned int> selected_channels;
     sample_index_t offset = 0;
     sample_index_t length = 0;
-    length = selection(&selected_channels, &offset, Q_NULLPTR, true);
+    length = selection(&selected_channels, &offset, nullptr, true);
 
     // abort if nothing is selected
     if (!length || selected_channels.isEmpty())
@@ -240,7 +240,7 @@ int Kwave::SonagramPlugin::start(QStringList &params)
     } else {
         // overview cache is no longer needed
         delete m_overview_cache;
-        m_overview_cache = Q_NULLPTR;
+        m_overview_cache = nullptr;
     }
 
     // connect all needed signals
@@ -298,7 +298,7 @@ void Kwave::SonagramPlugin::makeAllValid()
             if (selected_tracks.contains(signalManager().uuidOfTrack(track)))
                 track_list.append(track);
     }
-    const unsigned int tracks = track_list.count();
+    const unsigned int tracks = static_cast<unsigned int>(track_list.count());
 
     Kwave::WindowFunction func(window_type);
     const QVector<double> windowfunction = func.points(fft_points);
@@ -359,7 +359,7 @@ void Kwave::SonagramPlugin::makeAllValid()
 
             // run the FFT in a background thread
             synchronizer.addFuture(QtConcurrent::run(
-                this, &Kwave::SonagramPlugin::calculateSlice, slice)
+                &Kwave::SonagramPlugin::calculateSlice, this, slice)
             );
         } else {
             // range has been deleted -> fill with "empty"
@@ -533,7 +533,7 @@ void Kwave::SonagramPlugin::validate()
     }
 
     // queue a background thread for updates
-    m_future = QtConcurrent::run(this, &Kwave::SonagramPlugin::makeAllValid);
+    m_future = QtConcurrent::run(&Kwave::SonagramPlugin::makeAllValid, this);
 }
 
 //***************************************************************************
@@ -608,13 +608,13 @@ void Kwave::SonagramPlugin::windowDestroyed()
 {
     cancel();
 
-    m_sonagram_window = Q_NULLPTR; // closes itself !
+    m_sonagram_window = nullptr; // closes itself !
 
-    if (m_selection) delete m_selection;
-    m_selection = Q_NULLPTR;
+    delete m_selection;
+    m_selection = nullptr;
 
-    if (m_overview_cache) delete m_overview_cache;
-    m_overview_cache = Q_NULLPTR;
+    delete m_overview_cache;
+    m_overview_cache = nullptr;
 
     release();
 }
@@ -623,3 +623,5 @@ void Kwave::SonagramPlugin::windowDestroyed()
 #include "SonagramPlugin.moc"
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_SonagramPlugin.cpp"
